@@ -80,7 +80,7 @@ eh_test_subtype <- function(label, M, factors, data, digits = 2) {
   }
 
   # Check if M is a numeric variable >=2
-  if (class(M) != "numeric" | M < 2) {
+  if (!is.numeric(M) | M < 2) {
     stop("The argument to M, the total number of subtypes, must be a numeric value >=2.")
   }
 
